package
module
Version:
v0.0.0-...-b241907
Opens a new window with list of versions in this module.
Published: May 21, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package pagination is a simple pagination token generator
type Page struct {
OffsetID string `json:"offset_id"`
OffsetTimeAtUTC int64 `json:"offset_time_at_utc"`
PageSize int64 `json:"page_size"`
}
Page represents the next page for the query
Encode returns the Token type for a page
Token represents the encoded pagination
Decode returns the Page for a given token
Source Files
¶
Click to show internal directories.
Click to hide internal directories.